@@ -22,5 +22,5 @@ def longest_increasing_subsequence(sequence):
         for j in range(0, i):
             if sequence[i] > sequence[j]:
                 counts[i] = max(counts[i], counts[j] + 1)
-                print(counts)
+                #print(counts)
     return max(counts)
