@@ -32,14 +32,14 @@ def print_optimal_solution(optimal_solution,i,j):
         print_optimal_solution(optimal_solution,optimal_solution[i][j]+1,j)
         print(")",end = " ")
 
-def main():
-    array=[30,35,15,5,10,20,25]
-    n=len(array)
-    #Size of matrix created from above array will be
-    # 30*35 35*15 15*5 5*10 10*20 20*25
-    matrix , optimal_solution = matrix_chain_order(array)
-
-    print("No. of Operation required: "+str((matrix[1][n-1])))
-    print_optimal_solution(optimal_solution,1,n-1)
-if __name__ == '__main__':
-    main()
+# def main():
+#     array=[30,35,15,5,10,20,25]
+#     n=len(array)
+#     #Size of matrix created from above array will be
+#     # 30*35 35*15 15*5 5*10 10*20 20*25
+#     matrix , optimal_solution = matrix_chain_order(array)
+#
+#     print("No. of Operation required: "+str((matrix[1][n-1])))
+#     print_optimal_solution(optimal_solution,1,n-1)
+# if __name__ == '__main__':
+#     main()
