@@ -14,8 +14,11 @@ def can_attend_meetings(intervals):
     :type intervals: List[Interval]
     :rtype: bool
     """
-    intervals = sorted(intervals, key=lambda x: x.start)
+    intervals = sorted(intervals, key=lambda x: x[0])
     for i in range(1, len(intervals)):
-        if intervals[i].start < intervals[i - 1].end:
+        if intervals[i][0] < intervals[i - 1][1]:
             return False
     return True
+
+
+
